"""
toCase

toCase is a Case converter made in python, for peoples who wants simplify this feature. It can convert to and from Camel, Pascal, Snake, Kebab and Strings Sentences.
"""

from .rb_tocase import *

__version__ = "1.3.1"
__author__ = 'RickBarretto'
__credits__ = 'RickBarretto'